@@ -35,9 +35,9 @@ char *__process_states[] = {"created", "starting", "running", "stopping", "stopp
 
 // websocket protocols
 static const struct lws_protocols protocols[] = {
-        {"http-only", callback_http, sizeof(struct pss_http),   0},
-        {"tty",       callback_tty,  sizeof(struct tty_client), 0},
-        {NULL, NULL, 0, 0}
+        {"http-only", callback_http, sizeof(struct pss_http),   8192, 0, NULL, 0},
+        {"tty",       callback_tty,  sizeof(struct tty_client), 8192, 0, NULL, 0},
+        {NULL, NULL, 0, 0, 0, NULL, 0}
 };
 
 // websocket extensions
@@ -198,6 +198,8 @@ size_t circular_append(circbuf_t *circular, uint8_t *data, size_t length) {
 
     memcpy(circular->writer, data + bufremain, length - bufremain);
     circular->writer += length - bufremain;
+
+    return length;
 }
 
 buffer_t *circular_get(circbuf_t *circular, size_t length) {
@@ -496,9 +498,10 @@ void tty_server_free(struct tty_server *ts) {
 
     // free(ts->command);
     free(ts->prefs_json);
-    int i = 0;
 
     /*
+    int i = 0;
+
     do {
         free(ts->argv[i++]);
 
@@ -566,7 +569,7 @@ static int process_init(struct tty_process *process) {
             warnp("execvp");
         }
 
-        return 1;
+        exit(1);
     }
 
     verbose("[+] subprocess: started process, pid: %d, pty: %d\n", pid, pty);
@@ -629,7 +632,7 @@ int process_monitor(struct tty_process *process) {
         }
 
         // keeping logs into our circular buffer
-        circular_append(process->logs, pty_buffer, pty_len);
+        circular_append(process->logs, (uint8_t *) pty_buffer, pty_len);
 
         struct tty_client *client;
         LIST_FOREACH(client, &server->clients, list) {
@@ -687,7 +690,7 @@ int main(int argc, char **argv) {
     info.options = LWS_SERVER_OPTION_VALIDATE_UTF8 | LWS_SERVER_OPTION_DISABLE_IPV6;
     info.extensions = extensions;
 
-    int debug_level = LLL_ERR | LLL_WARN | LLL_NOTICE | LLL_DEBUG | LLL_PARSER | LLL_HEADER;
+    int debug_level = LLL_ERR | LLL_WARN | LLL_NOTICE; // | LLL_DEBUG | LLL_PARSER | LLL_HEADER;
     char *chrooting = NULL;
     char iface[128] = "";
     bool ssl = false;
@@ -926,8 +929,9 @@ int main(int argc, char **argv) {
 
     // libwebsockets main loop
     while(!force_exit) {
-        lws_service(context, 10);
+        lws_service(context, -1);
         process_watch();
+        usleep(5000);
     }
 
     printf("[+] exiting\n");
